@@ -18,12 +18,16 @@
      * Elund3 /500./,
 #endif
      * SucPw /1.5/,
-     * MulLow /0/,
+     * MulLow /1/,      ! old one is 0. bef. v.5.0
      * LundPara /1, 2, 0, 0, 1, 5*0/,
      * IntModel /'int1'/ ,
-     * InclusiveFile /'../Contrib/Inclusive/xdist.d'/ ,
+     * InclusiveFile /'../../Contrib/Inclusive/xdist.d'/ ,
      * Efermi /10.e-3/
        data 
      * Eta2Pi0/0.2/,
-     * SucInt /1/
+#ifdef IBMAIX
+     * SucInt /0/
+#else
+     * SucInt /0/     ! old one was 1; changed
+#endif
       end
