@@ -6,7 +6,7 @@ c	(->	---------------------------------------------------
 	real*8  HeightList  !1  Height of observation levels in m. This is  made from DepthList internally. 
                             ! I.e., this one is usually not an input. However, if the DepthList values are 
                             ! negative, this is used as input and corresponding DepthList is computed internally.
-        real*8  DepthList   !1	Depth List of Observation level in kg/m2.  If < 0, HeightList has priority. 
+        real*8  DepthList   !1	Depth List of Observation level in kg/m$^2$. If $< 0$, HeightList has priority. 
                             !  (See HeightList)
         real*8  ASHeightList	!1  This is HeightList for Air Shower observ.  Used only if Generate contains
                             !  "as". See  HeightList.
@@ -15,18 +15,20 @@ c	(->	---------------------------------------------------
         real*8  LatitOfSite     !1  Latitude of the deepest observation level in degree.  East is positive.
         real*8  LongitOfSite    !1  Longitude of the deepest observation level in degree.  North is positive.
      	real*8  DtGMT           !1  Difference of the local time of the observation place from GMT (hour).
-	real*8  YearOfGeomag    !1  Like 1994.5. Year when Geomagnetic field is to be calculated.
-	integer ObsPlane        !1   How to observe particles.
-                 ! 0==> no detector plane is used for observation. BorderHeightL is used to  detect particles. This is
-                 !      for, say,  neutrino observation. See  BorderHeightL.  (HeigtList and   DepthList are neglected.
-                 !      ASHeightList and ASDepthList are still used to  observe Air Shower.)
-                 ! 1 or -1==> detector at the observation place  is horizontal. If <0, particle coordinate given 
-                 !            in UserHook is the one in the Exyz system.
-                 ! 2 or -2==> detector is perpendicular to the primary. For <0, see the above.
-                 ! 3==> detector is user defined (not supported)
+	real*8  YearOfGeomag    !1  Like 1999.5. Year when Geomagnetic field is to be calculated.
+	integer ObsPlane        !1    How to observe particles. \newline
+                                !    0$ \Rightarrow $ no detector plane is used for observation. BorderHeightL
+                                !     is used to detect particles. This is for, say, neutrino observation. See 
+                                !     BorderHeightL. (HeigtList and DepthList are neglected. ASHeightList and 
+                                !     ASDepthList are still used to observe Air Shower.)\newline
+                                !    1$ \Rightarrow $ detector at the observation place is horizontal. \newline
+                                !    2$ \Rightarrow $ detector is perpendicular to the primary. \newline
+                                !    3$ \Rightarrow $ detector is user defined (not supported) 
+
+             
         integer NoOfSites2    !2   No of Sites for particle observation; not to be touched; for skeleton/flesh use.
 	real*8 XaxisFromSouth   !2 Angle between the horizontal detector X-axis and the south(deg). + is counter
-                                ! clockwise.  If |XaxisFromSouth| > 360, it is computed so that the direction is
+                                ! clockwise.  If $|$XaxisFromSouth$| > 360$, it is computed so that the direction is
                                 ! to the magnetic east at the deepest observation point. Default is 361.
 c	<-)	--------------------------------------------
 
