@@ -6,9 +6,13 @@ c	(->	--------------------------------------------
         logical IncMuonPolari  !1  if T, consider muon polarization
         logical Freec          !1  if F, the first interaction point is made to be the injection point else randomly
                                !    sampled.
-	integer OneDim	       !1  If 0, 3 dimensional simulation. if 1, one
-                               !  dimensional simulation is performed.  For flux calculation,
-                               ! sometimes one dimensional one is better. 
+	integer OneDim	       !1  If 0, 3 dimensional simulation. if >=1, one
+                               !  dimensional simulation is performed.  For flux calculation, sometimes one 
+                               !  dimensional one is better. 
+                               !  1: onedim without use of table.
+                               !  2: table is used for thickness <--> length conversion. if cos < .5
+                               !  3: table is always used for any angle.
+                               !  ( for height > 30 km, table is not used in any case). 
 	real*8  Truncc         !2 coeff. for truncating path.
 	real*8  Truncn         !2 coeff. for truncating path.
 	real*8  Truncx         !2 coeff. for truncating path.
@@ -29,13 +33,13 @@ c	(->	--------------------------------------------
         integer EndLevel2 !2  Don't worry. This  is system use.
 	integer Trace   !1  Flag for trace information output.
             !   0 ==> no trace information is output.
-            !  <10==> x, y, z in the primary system   (say, 1)
-            !  <20 ==> x, y, in the primary system. z in kg/m2. (say,11)
-            !  <30 ==> x, y, z in the detector system           
+            !  <10==> x, y, z in the primary system(say, 1)
+            !  <20 ==> x, y, in the primary sys. z in kg/m2.(say,11)
+            !  <30 ==> x, y, z in the detector system
             !  <40 ==> x, y, in the detector system. z in kg/m2 
-            !  <50 ==> x, y, z in 'xyz' system
+            !  <50 ==> x, y, z in 'xyz' system.
             !  <60 ==> x,y, in 'xyz' and z in kg/m2
-            !  61-100 ==>  for Cherenkov observation. For Coord system subtract 60.
+            !  61-100 ==>  for Cherenkov observation. For Coord system,  subtract 60.
             !   if the value is even,  binary output is made on TraceDev.
             !  > 101  ==> subtract 100 and apply the above, but chookTrace or chookCeren["",S,E] are used.
             !  Primary system:  Origin is the deepest detector.  Z-axis is the primary direction. 
@@ -69,7 +73,8 @@ c	(->	--------------------------------------------
 
         real*8  MagChgDist    !2 Distance where mag. can be seen  as const.(m) at sea level
 	real*8  BorderHeightH !2 If a particle goes higher than this, discard it.  This should be larger than HeightOfInj or 0.  
-                              !  If 0, it is adjusted to be the same as HeightOfInj.
+                              !  If 0, it is adjusted to be the same as HeightOfInj. NOTE: For upgoin primary cases, you have
+                              !  to set this one explicitly. 
 	real*8  BorderHeightL !2 If a particle reaches this hight, call observation routine. No further tracking is done. 
                               !  This is for neutrino observation.  See ObsPlane.
         real*8  BackAngLimit  !2 If the cosine of the angle between a particle and the primary becomes smaller than
@@ -126,13 +131,26 @@ c	(->	--------------------------------------------
                               !   this will not be effective because of BackAnglLimit. See Reverse.
                               !   TimeStructure should be T if Reverse != 0 and PathLimit is to be effective.
 
+       integer MuNI           !2 0--> nuclear interaction of muon is completely neglected
+                              !  1--> energy loss by n.i is subsumed in dE/dx of muons as a continuous energy loss.  Let v=
+                              !     E_transfer/Emu,  the loss here is Int(vc:vmax) of (Emu vdsigma/dv).  (vc ~0, vmax~1).
+                              !  2--> (Default value). similar to 1 but as the continuous loss only v < vmin=10^-3 of the
+                              !     fractional muon energy is subsumed (Int(vc: vmin) of (Emu vdsigma/dv)).  The portion
+                              !     of loss by v>vmin is treated as a stocastic  process.  However, the product from the
+                              !     n.i itself is neglected 
+                              !  3--> the same as 2, but the n.i is explicitly included to produce a number of particles.  
+                              !     The n.i is treated as a photo-nucleus interaction.
+
+       integer MuBr           !2  parameter similar to MuNI but for bremsstrahlung by muons.
+       integer MuPr           !2  parameter similar to MuNI but for pair creation by muons.
+
 c	 <-)	----------------------------------------------
 
 	common /cZtracp/ Truncc, Truncn, Truncx, 
      *  KEminObs, KEminObs2, RatioToE0, PathLimit,
      *  WaitRatio,  EthinRatio, BackAngLimit,
      *  BorderHeightH,  MagN, MagE, MagD, MagChgDist,
-     *  BorderHeightL, 
+     *  BorderHeightL,  MuNI, MuBr, MuPr,
      *  MagBremEmin, MagPairEmin, UpsilonMin, LpmBremEmin, 
      *  LpmPairEmin,
      *  ThinSampling, TimeStructure, HowGeomag, 
