@@ -3,6 +3,7 @@ c
       subroutine cbeginRun
       implicit none
 #include  "Zmanagerp.h"
+#include  "Zelemagp.h"
 #include  "Zevhnp.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
@@ -15,6 +16,15 @@ c
       character*70 msg
       character*16 temp
       integer jold
+      real*8 s1
+
+      if(Cont) then
+c           restore status at the end of previous run
+         call crestoreStatus
+      elseif(Job .eq. 'flesh' ) then
+         call cgetSkelFile 
+         Job = 'flesh'    ! Job='flesh' is kept as now
+      endif
 
 c        reset parameters.
       if(BorderHeightH .eq. 0.0) then
@@ -25,11 +35,6 @@ c        reset parameters.
          DestEventNo(2) = DestEventNo(1)
       endif
 
-      if(Cont) then
-c           restore status at the end of previous run
-         call crestoreStatus
-      endif
-
 c         to lower case letters.
       temp = Generate
       call c2lowerCase(temp, Generate)
@@ -50,6 +55,9 @@ c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
          write(msg, *) 'IntModel=', IntModel,' not supported'
          call cerrorMsg(msg, 0)
       endif
+c        init for LPM effect energy sampling.
+      s1 = (7.36d0**(1./3.d0)/183.d0)**2
+      call csetLPMCnst(s1, log(s1), 1.d-4, X0)
 c        initialize  observation  
       call cinitObs
 c        init for   primary sampling
@@ -58,6 +66,11 @@ c        init for   primary sampling
       if(CutOffFile .ne. ' ') then
          call crigCut0(CutOffFile) ! read cutoff talbe and init.
       endif
+c       init for muon interaction routines; specific for Air.
+      call cRdmuTab        ! set various consts for mu int.
+      call cSetMu(7.36d0, 14.7d0)
+      FromEpics = .false.  ! muon interaction routines for Air are
+                           ! inside Cosmos 
 
       call ciniSPrimAng    !  this is in csPrimaAgn.f in Tracking dir.
       call ciniTracking0  !  init for  tracking for all events
@@ -123,8 +136,8 @@ c     ************
 c   
 c
 c
-      character*90  msg
-      integer klena
+      character*190  msg
+      integer klena, icon
       character*8  uid 
 
       if(Job .eq. ' ' .or. Job .eq. 'skeleton') then
@@ -139,15 +152,29 @@ c                  open seed file for output
                write(msg, *) 'opening SeedFile=',
      *         SeedFile(1:klena(SeedFile))
                call cerrorMsg(msg, 1)
-               open(SeedFileDev, file=SeedFile, form='formatted')
+               call copenfw(SeedFileDev, SeedFile, icon)
+               if(icon .ne. 0) then
+                  call cerrorMsg(SeedFile, 1)
+                  call cerrorMsg('File shown above cannot be opened',0)
+               endif
+               if(Cont) then
+                  call cskiptoEOF(SeedFileDev)
+               endif
             endif               
          elseif(Job .eq. 'skeleton') then
             call
      *      cerrorMsg('  ********** skeleton making **********', 1)
             write(msg, *)  '      Generate=', Generate
             call cerrorMsg(msg, 1)
-c               save skeleton inf. in skelotonFile file.
-            open(TempDev, file=SkeletonFile, form='formatted')
+c                 save skeleton inf. in skelotonFile file.
+c             The file will be modified when the distjob command
+c             processes Job = 'flesh' later. You need not modify
+c             skeleton file if distjob is employed.
+            call copenfw(TempDev, SkeletonFile, icon)
+            if(icon .ne. 0) then
+               call cerrorMsg(SkeletonFile, 1)
+               call cerrorMsg('File shown above cannot be opened',0)
+            endif
             call cwriteParam(TempDev, 1)
             close(TempDev)
 c                open SeedFile 
@@ -160,7 +187,14 @@ c                error. you need file
                write(msg, *) 'opening SeedFile=',
      *         SeedFile(1:klena(SeedFile))
                call cerrorMsg(msg, 1)
-               open(SeedFileDev, file=SeedFile, form='formatted')
+               call copenfw(SeedFileDev, SeedFile, icon)
+               if(icon .ne. 0) then
+                  call cerrorMsg(SeedFile, 1)
+                  call cerrorMsg('File shown above cannot be opened',0)
+               endif
+               if(Cont) then
+                  call cskiptoEOF(SeedFileDev)
+               endif
             endif
          endif
       elseif(Job   .eq. 'flesh') then
@@ -191,7 +225,11 @@ c                open SeedFile
              write(msg, *) 'opening SeedFFile=', 
      *        SeedFile(1:klena(SeedFile))
              call cerrorMsg(msg, 1)
-             open(SeedFileDev, file=SeedFile, form='formatted')
+             call copenf(SeedFileDev, SeedFile, icon)
+             if(icon .ne. 0) then
+                call cerrorMsg(SeedFile, 0)
+                call cerrorMsg('File shown above seems missing',0)
+             endif
           endif
       else
            write(msg,*) ' Job=',Job, ' undefined'
@@ -209,7 +247,28 @@ c        **************************************** read cont job info
       subroutine crestoreStatus
       implicit none
 #include "Zmanagerp.h"
-      open(TempDev, file=ContFile, form='formatted')
+      integer icon
+
+      call copenf(TempDev, ContFile,icon)
+      if(icon .ne. 0) then
+         call cerrorMsg(ContFile, 1)
+         call cerrorMsg('File shown above seems missing',0)
+      endif
       call creadParam(TempDev)
       close(TempDev)
       end
+      subroutine cgetSkelFile
+      implicit none
+#include "Zmanagerp.h"
+      integer icon
+      call copenf(TempDev, SkeletonFile, icon)
+      if(icon .ne. 0 ) then
+         call cerrorMsg(SkeletonFile, 1)
+         call cerrorMsg('File shown above seems missing',0)
+      endif
+c          read skelton parameters for flesing
+      call creadParam(TempDev)
+      close(TempDev)
+      end
+
+
