@@ -64,13 +64,13 @@ c              to 'hva'
      * MagfieldNED, MagfieldHVA)
        call ctransMagTo('xyz',    ObsSites(NoOfSites).pos.xyz, 
      * MagfieldNED, MagfieldXYZ)
-
-c              assume the x-axis is directed to mag.east.
+       if(abs(XaxisFromSouth) .gt. 360.d0) then
+c           if it is > 360, use magnetic east to be the detector x-axis. 
 c           angle form south to x-axis in counter closckwise.
 c        Note:   'hva' system angle  + is clockwise.
-c       XaxisFromSouth = 90.0 - MagfieldHVA.a
-
-       XaxisFromSouth = 90.0 - MagfieldHVA.x
+c       XaxisFromSouth = 90.0 - MagfieldHVA.x
+          XaxisFromSouth = 90.0 - MagfieldHVA.x
+       endif
 
 c          celestial coord. init.
        call kcelei(LatitOfSite, 
